/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/example.xml" }
 */

import { select, toTextArr, toTextContentArr } from "../util";
import { SoftwareListType, DCCDocument, SoftwareType } from "../../src";

const base = "/dcc:digitalCalibrationCertificate/dcc:administrativeData/dcc:dccSoftware/dcc:software";
const xpath = {
  software: {
    name: {
      content: `${base}/dcc:name/dcc:content`,
    },
    release: `string(${base}/dcc:release)`,
    type: `string(${base}/dcc:type)`,
    description: `${base}/dcc:description`,
    _id: `${base}/@id`,
    _refType: `${base}/@refType`,
  },
};

describe("DccSoftwareType", () => {
  let dcc: DCCDocument, dccSoftware: SoftwareListType, software: SoftwareType, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    dccSoftware = dcc.digitalCalibrationCertificate.administrativeData.dccSoftware;
    software = dccSoftware.software[0];
  });

  test("should get correct software name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.software.name.content, dom);
    expect(toTextArr(software.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct software release version of software from XML", () => {
    expect(software.release._text).toBe(select(xpath.software.release, dom));
  });
});
