/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/GP_Temperature_Simplified.xml" }
 */

import { select, toTextArr, toTextContentArr } from "../../util";
import { DCCDocument, ResultType } from "../../../src";

const base = "/dcc:digitalCalibrationCertificate/dcc:measurementResults/dcc:measurementResult[1]/dcc:results";
const xpath = {
  measurementResults: {
    measurementResult: {
      results: {
        result: {
          name: {
            content: `${base}/dcc:result[1]/dcc:name/dcc:content`,
          },
          data: {
            list: {
              quantity1: {
                name: {
                  content: `${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[1]/dcc:name/dcc:content`,
                },
                si_hybrid: {
                  si_realListXMLList1: {
                    si_valueXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[1]/si:hybrid/si:realListXMLList[1]/si:valueXMLList)`,
                    si_unitXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[1]/si:hybrid/si:realListXMLList[1]/si:unitXMLList)`,
                  },
                  si_realListXMLList2: {
                    si_valueXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[1]/si:hybrid/si:realListXMLList[2]/si:valueXMLList)`,
                    si_unitXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[1]/si:hybrid/si:realListXMLList[2]/si:unitXMLList)`,
                  },
                },
                refType: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[1]//@refType)`,
              },
              quantity2: {
                name: {
                  content: `${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[2]/dcc:name/dcc:content`,
                },
                si_hybrid: {
                  si_realListXMLList1: {
                    si_valueXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[2]/si:hybrid/si:realListXMLList[1]/si:valueXMLList)`,
                    si_unitXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[2]/si:hybrid/si:realListXMLList[1]/si:unitXMLList)`,
                  },
                  si_realListXMLList2: {
                    si_valueXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[2]/si:hybrid/si:realListXMLList[2]/si:valueXMLList)`,
                    si_unitXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[2]/si:hybrid/si:realListXMLList[2]/si:unitXMLList)`,
                  },
                },
                refType: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[2]//@refType)`,
              },
              quantity3: {
                name: {
                  content: `${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/dcc:name/dcc:content`,
                },
                si_realListXMLList: {
                  si_valueXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/si:realListXMLList[1]/si:valueXMLList)`,
                  si_unitXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/si:realListXMLList[1]/si:unitXMLList)`,
                  si_expandedUncXMLList: {
                    si_uncertaintyXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/si:realListXMLList[1]/si:expandedUncXMLList/si:uncertaintyXMLList)`,
                    si_coverageFactorXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/si:realListXMLList[1]/si:expandedUncXMLList/si:coverageFactorXMLList)`,
                    si_coverageProbabilityXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/si:realListXMLList[1]/si:expandedUncXMLList/si:coverageProbabilityXMLList)`,
                    si_distributionXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/si:realListXMLList[1]/si:expandedUncXMLList/si:distributionXMLList)`,
                  },
                },
                measurementMetaData: {
                  metaData: {
                    declaration: {
                      name: {
                        content: `${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/dcc:measurementMetaData/dcc:metaData[1]/dcc:declaration/dcc:name/dcc:content`,
                      },
                    },
                    conformityXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/dcc:measurementMetaData/dcc:metaData/dcc:conformityXMLList)`,
                    data: {
                      quantity1: {
                        si_realListXMLList: {
                          si_valueXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/dcc:measurementMetaData/dcc:metaData/dcc:data/dcc:quantity[1]/si:realListXMLList/si:valueXMLList)`,
                          si_unitXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/dcc:measurementMetaData/dcc:metaData/dcc:data/dcc:quantity[1]/si:realListXMLList/si:unitXMLList)`,
                        },
                        refType: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/dcc:measurementMetaData/dcc:metaData/dcc:data/dcc:quantity[1]//@refType)`,
                      },
                      quantity2: {
                        si_realListXMLList: {
                          si_valueXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/dcc:measurementMetaData/dcc:metaData/dcc:data/dcc:quantity[2]/si:realListXMLList/si:valueXMLList)`,
                          si_unitXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/dcc:measurementMetaData/dcc:metaData/dcc:data/dcc:quantity[2]/si:realListXMLList/si:unitXMLList)`,
                        },
                        refType: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/dcc:measurementMetaData/dcc:metaData/dcc:data/dcc:quantity[2]//@refType)`,
                      },
                    },
                    refType: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/dcc:measurementMetaData/dcc:metaData//@refType)`,
                  },
                },
                refType: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/@refType)`,
              },
              refType: `string(${base}/dcc:result[1]/dcc:data/dcc:list//@refType)`,
            },
          },
          refType: `string(${base}/dcc:result[1]//@refType)`,
        },
      },
    },
  },
};

describe("GP_DCC_Temperature_Simplified: ResultType", () => {
  let dcc: DCCDocument, result: ResultType, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    result = dcc.digitalCalibrationCertificate.measurementResults.measurementResult[0].results.result[0];
  });

  test("should get correct result name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.results.result.name.content, dom);
    expect(toTextArr(result.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct result quantity 1 name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.results.result.data.list.quantity1.name.content, dom);
    expect(toTextArr(result.data.list[0].quantity[0].name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct result quantity 1 hybrid si:valueXMLList 1 from XML", () => {
    expect(result.data.list[0].quantity[0].hybrid.realListXMLList[0].valueXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity1.si_hybrid.si_realListXMLList1.si_valueXMLList, dom),
    );
  });

  test("should get correct result quantity 1 hybrid si:unitXMLList 1 from XML", () => {
    expect(result.data.list[0].quantity[0].hybrid.realListXMLList[0].unitXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity1.si_hybrid.si_realListXMLList1.si_unitXMLList, dom),
    );
  });

  test("should get correct result quantity 1 hybrid si:valueXMLList 2 from XML", () => {
    expect(result.data.list[0].quantity[0].hybrid.realListXMLList[1].valueXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity1.si_hybrid.si_realListXMLList2.si_valueXMLList, dom),
    );
  });

  test("should get correct result quantity 1 hybrid si:unitXMLList 2: from XML", () => {
    expect(result.data.list[0].quantity[0].hybrid.realListXMLList[1].unitXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity1.si_hybrid.si_realListXMLList2.si_unitXMLList, dom),
    );
  });

  test("should get correct result quantity 2 name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.results.result.data.list.quantity2.name.content, dom);
    expect(toTextArr(result.data.list[0].quantity[1].name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct result quantity 2 hybrid si:valueXMLList 1 from XML", () => {
    expect(result.data.list[0].quantity[1].hybrid.realListXMLList[0].valueXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity2.si_hybrid.si_realListXMLList1.si_valueXMLList, dom),
    );
  });

  test("should get correct result quantity 2 hybrid si:unitXMLList 1 from XML", () => {
    expect(result.data.list[0].quantity[1].hybrid.realListXMLList[0].unitXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity2.si_hybrid.si_realListXMLList1.si_unitXMLList, dom),
    );
  });

  test("should get correct result quantity 2 hybrid si:valueXMLList 2 from XML", () => {
    expect(result.data.list[0].quantity[1].hybrid.realListXMLList[1].valueXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity2.si_hybrid.si_realListXMLList2.si_valueXMLList, dom),
    );
  });

  test("should get correct result quantity 2 hybrid si:unitXMLList 2: from XML", () => {
    expect(result.data.list[0].quantity[1].hybrid.realListXMLList[1].unitXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity2.si_hybrid.si_realListXMLList2.si_unitXMLList, dom),
    );
  });

  test("should get correct result quantity 3 name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.results.result.data.list.quantity3.name.content, dom);
    expect(toTextArr(result.data.list[0].quantity[2].name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct result quantity 3 si:valueXMLList from XML", () => {
    expect(result.data.list[0].quantity[2].realListXMLList.valueXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity3.si_realListXMLList.si_valueXMLList, dom),
    );
  });

  test("should get correct result quantity 3 si:unitXMLList from XML", () => {
    expect(result.data.list[0].quantity[2].realListXMLList.unitXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity3.si_realListXMLList.si_unitXMLList, dom),
    );
  });

  test("should get correct result quantity 3 uncertainty list from XML", () => {
    expect(result.data.list[0].quantity[2].realListXMLList.expandedUncXMLList.uncertaintyXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity3.si_realListXMLList.si_expandedUncXMLList.si_uncertaintyXMLList, dom),
    );
  });

  test("should get correct result quantity 3 uncertainty coverage factor list from XML", () => {
    expect(result.data.list[0].quantity[2].realListXMLList.expandedUncXMLList.coverageFactorXMLList._text).toBe(
      select(
        xpath.measurementResults.measurementResult.results.result.data.list.quantity3.si_realListXMLList.si_expandedUncXMLList.si_coverageFactorXMLList,
        dom,
      ),
    );
  });

  test("should get correct result quantity 3 uncertainty coverage probability list from XML", () => {
    expect(result.data.list[0].quantity[2].realListXMLList.expandedUncXMLList.coverageProbabilityXMLList._text).toBe(
      select(
        xpath.measurementResults.measurementResult.results.result.data.list.quantity3.si_realListXMLList.si_expandedUncXMLList.si_coverageProbabilityXMLList,
        dom,
      ),
    );
  });

  test("should get correct result quantity 3 uncertainty distribution list from XML", () => {
    expect(result.data.list[0].quantity[2].realListXMLList.expandedUncXMLList.distributionXMLList._text).toBe(
      select(
        xpath.measurementResults.measurementResult.results.result.data.list.quantity3.si_realListXMLList.si_expandedUncXMLList.si_distributionXMLList,
        dom,
      ),
    );
  });

  test("should get correct result quantity 3 meta data declaration name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity3.measurementMetaData.metaData.declaration.name.content, dom)
    );
    expect(toTextArr(result.data.list[0].quantity[2].measurementMetaData.metaData[0].declaration.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct result quantity 3 meta data conformityXMLList from XML", () => {
    expect(result.data.list[0].quantity[2].measurementMetaData.metaData[0].conformityXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity3.measurementMetaData.metaData.conformityXMLList, dom),
    );
  });

  test("should get correct result quantity 3 meta data quantity 1 si:valueXMLList from XML", () => {
    expect(result.data.list[0].quantity[2].measurementMetaData.metaData[0].data.quantity[0].realListXMLList.valueXMLList._text).toBe(
      select(
        xpath.measurementResults.measurementResult.results.result.data.list.quantity3.measurementMetaData.metaData.data.quantity1.si_realListXMLList
          .si_valueXMLList,
        dom,
      ),
    );
  });

  test("should get correct result quantity 3 meta data quantity 1 si:unitXMLList from XML", () => {
    expect(result.data.list[0].quantity[2].measurementMetaData.metaData[0].data.quantity[0].realListXMLList.unitXMLList._text).toBe(
      select(
        xpath.measurementResults.measurementResult.results.result.data.list.quantity3.measurementMetaData.metaData.data.quantity1.si_realListXMLList
          .si_unitXMLList,
        dom,
      ),
    );
  });

  test("should get correct result quantity 3 meta data quantity 2 si:valueXMLList from XML", () => {
    expect(result.data.list[0].quantity[2].measurementMetaData.metaData[0].data.quantity[1].realListXMLList.valueXMLList._text).toBe(
      select(
        xpath.measurementResults.measurementResult.results.result.data.list.quantity3.measurementMetaData.metaData.data.quantity2.si_realListXMLList
          .si_valueXMLList,
        dom,
      ),
    );
  });

  test("should get correct result quantity 3 meta data quantity 2 si:valueXMLList from XML", () => {
    expect(result.data.list[0].quantity[2].measurementMetaData.metaData[0].data.quantity[1].realListXMLList.valueXMLList._text).toBe(
      select(
        xpath.measurementResults.measurementResult.results.result.data.list.quantity3.measurementMetaData.metaData.data.quantity2.si_realListXMLList
          .si_valueXMLList,
        dom,
      ),
    );
  });

  test("should get correct result quantity 3 meta data quantity 2 si:unitXMLList from XML", () => {
    expect(result.data.list[0].quantity[2].measurementMetaData.metaData[0].data.quantity[1].realListXMLList.unitXMLList._text).toBe(
      select(
        xpath.measurementResults.measurementResult.results.result.data.list.quantity3.measurementMetaData.metaData.data.quantity2.si_realListXMLList
          .si_unitXMLList,
        dom,
      ),
    );
  });

  test("should get correct result refType from XML", () => {
    expect(result._attr.refType).toBe(select(xpath.measurementResults.measurementResult.results.result.refType, dom));
  });

  test("should get correct result data list refType from XML", () => {
    expect(result.data.list[0]._attr.refType).toBe(select(xpath.measurementResults.measurementResult.results.result.data.list.refType, dom));
  });

  test("should get correct result quantity 1 refType from XML", () => {
    expect(result.data.list[0].quantity[0]._attr.refType).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity1.refType, dom),
    );
  });

  test("should get correct result quantity2 refType from XML", () => {
    expect(result.data.list[0].quantity[1]._attr.refType).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity2.refType, dom),
    );
  });

  test("should get correct result quantity3 refType from XML", () => {
    expect(result.data.list[0].quantity[2]._attr.refType).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity3.refType, dom),
    );
  });

  test("should get correct result quantity 3 meta data refType from XML", () => {
    expect(result.data.list[0].quantity[2].measurementMetaData.metaData[0]._attr.refType).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity3.measurementMetaData.metaData.refType, dom),
    );
  });

  test("should get correct result quantity 2 refType from XML", () => {
    expect(result.data.list[0].quantity[1]._attr.refType).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity2.refType, dom),
    );
  });

  test("should get correct result quantity 3 refType from XML", () => {
    expect(result.data.list[0].quantity[2]._attr.refType).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity3.refType, dom),
    );
  });

  /* TODO: setters */
});
