/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/GP_Temperature_Simplified.xml" }
 */

import { select, toTextArr, toTextContentArr } from "../../util";
import { DCCDocument, UsedMethodListType } from "../../../src";

const base = "/dcc:digitalCalibrationCertificate/dcc:measurementResults/dcc:measurementResult[1]";
const xpath = {
  measurementResults: {
    measurementResult: {
      usedMethods: {
        usedMethod1: {
          name: {
            content: `${base}/dcc:usedMethods/dcc:usedMethod[1]/dcc:name/dcc:content`,
          },
          refType: `string(${base}/dcc:usedMethods/dcc:usedMethod[1]//@refType)`,
        },
      },
    },
  },
};

describe("GP_DCC_Temperature_Simplified: UsedMethodListType", () => {
  let dcc: DCCDocument, usedMethods: UsedMethodListType, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    usedMethods = dcc.digitalCalibrationCertificate.measurementResults.measurementResult[0].usedMethods;
  });

  test("should get correct used method 1 name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.usedMethods.usedMethod1.name.content, dom);
    expect(toTextArr(usedMethods.usedMethod[0].name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct used method 1 refType from XML", () => {
    expect(usedMethods.usedMethod[0]._attr.refType).toBe(select(xpath.measurementResults.measurementResult.usedMethods.usedMethod1.refType, dom));
  });

  /* TODO: setters */
});
