/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/GP_Temperature_Simplified_variant.xml" }
 */

import * as fc from "fast-check";
import { select, toTextArr, toTextContentArr, indexOf } from "../../util";
import { StatementMetaDataType, DCCDocument, DCCXMLElement } from "../../../src";
import { string_ISO3166_1 } from "../../Arbitraries";

const base = "/dcc:digitalCalibrationCertificate/dcc:administrativeData/dcc:statements";
const xpath = {
  statements: {
    statement3: {
      countryCodeISO3166_1: `${base}/dcc:statement[3]/dcc:countryCodeISO3166_1`,
      convention: `string(${base}/dcc:statement[3]/dcc:convention)`,
      traceable: `string(${base}/dcc:statement[3]/dcc:traceable)`,
      period: `string(${base}/dcc:statement[3]/dcc:period)`,
      nonSIDefinition: `string(${base}/dcc:statement[3]/dcc:nonSIDefinition)`,
      nonSIUnit: `string(${base}/dcc:statement[3]/dcc:nonSIUnit)`,
    },
  },
};

describe("GP_DCC_Temperature_Simplified: StatementMetaDataType", () => {
  let dcc: DCCDocument, statement3: StatementMetaDataType, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    statement3 = dcc.digitalCalibrationCertificate.administrativeData.statements.statement[2];
  });

  test("should get correct statement 3 countryCodeISO3166_1 from XML", () => {
    const expected = <Element[]>select(xpath.statements.statement3.countryCodeISO3166_1, dom);
    expect(toTextArr(statement3.countryCodeISO3166_1)).toEqual(toTextContentArr(expected));
  });

  test("should get correct statement 3 convention from XML", () => {
    const expected = select(xpath.statements.statement3.convention, dom);
    expect(statement3.convention._text).toEqual(expected);
  });

  test("should get correct statement 3 traceable from XML", () => {
    const expected = select(xpath.statements.statement3.traceable, dom);
    expect(statement3.traceable._text).toEqual(expected);
  });

  test("should get correct statement 3 period from XML", () => {
    const expected = select(xpath.statements.statement3.period, dom);
    expect(statement3.period._text).toEqual(expected);
  });

  test("should get correct statement 3 nonSIDefinition from XML", () => {
    const expected = select(xpath.statements.statement3.nonSIDefinition, dom);
    expect(statement3.nonSIDefinition._text).toEqual(expected);
  });

  test("should get correct statement 3 nonSIUnit from XML", () => {
    const expected = select(xpath.statements.statement3.nonSIUnit, dom);
    expect(statement3.nonSIUnit._text).toEqual(expected);
  });

  /* test for setters */
  test("should set statement 3 countryCodeISO3166_1 correctly", () => {
    fc.assert(
      fc.property(string_ISO3166_1(), (str) => {
        // add new element to array
        statement3.countryCodeISO3166_1.push(new DCCXMLElement({ _text: str }));

        // get actual list from xml
        const actual = <Element[]>select(xpath.statements.statement3.countryCodeISO3166_1, dcc);

        expect(toTextArr(statement3.countryCodeISO3166_1)).toContain(str);
        expect(toTextContentArr(actual)).toContain(str);
      }),
    );
  });

  test("should delete statement 3 countryCodeISO3166_1 correctly", () => {
    const selection = toTextContentArr(<Element[]>select(xpath.statements.statement3.countryCodeISO3166_1, dom));
    fc.assert(
      fc.property(fc.constantFrom(...selection), (str) => {
        // get index and remove element from array
        const index = indexOf(statement3.countryCodeISO3166_1, str);
        statement3.countryCodeISO3166_1.splice(index, 1);

        // get actual list from xml
        const actual = <Element[]>select(xpath.statements.statement3.countryCodeISO3166_1, dcc);

        expect(toTextArr(statement3.countryCodeISO3166_1)).not.toContain(str);
        expect(toTextContentArr(actual)).not.toContain(str);
      }),
    );
  });
});
