/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/GP_Temperature_v3.2.0_DCC.xml" }
 */

import { select, toTextArr, toTextContentArr } from "../../util";
import { ContactType, DCCDocument, LocationType } from "../../../src";

const base = "/dcc:digitalCalibrationCertificate/dcc:administrativeData/dcc:customer";
const xpath = {
  customer: {
    name: {
      content: `${base}/dcc:name/dcc:content`,
    },
    email: `string(${base}/dcc:eMail)`,
    location: {
      city: `${base}/dcc:location/dcc:city[1]`,
      countryCode: `${base}/dcc:location/dcc:countryCode[1]`,
      postCode: `${base}/dcc:location/dcc:postCode[1]`,
      further: `${base}/dcc:location/dcc:further[1]/dcc:content`,
    },
    descriptionData: `${base}/dcc:descriptionData`,
    _id: `${base}/@id`,
  },
};

describe("GP_Temperature_v3.2.0_DCC: ContactType", () => {
  let dcc: DCCDocument, customer: ContactType, location: LocationType, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    customer = dcc.digitalCalibrationCertificate.administrativeData.customer;
    location = customer.location; /* TODO: check iff this variable is used anywhere */
  });

  test("should get correct customer name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.customer.name.content, dom);
    expect(toTextArr(customer.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct customer email address from XML", () => {
    expect(customer.eMail._text).toBe(select(xpath.customer.email, dom));
  });

  test("should get correct customer location city from XML", () => {
    const expected = <Element[]>select(xpath.customer.location.city, dom);
    expect(customer.location.city[0]._text).toEqual(toTextContentArr(expected)[0]);
  });

  test("should get correct customer location county code from XML", () => {
    const expected = <Element[]>select(xpath.customer.location.countryCode, dom);
    expect(customer.location.countryCode[0]._text).toEqual(toTextContentArr(expected)[0]);
  });

  test("should get correct customer location post code from XML", () => {
    const expected = <Element[]>select(xpath.customer.location.postCode, dom);
    expect(customer.location.postCode[0]._text).toEqual(toTextContentArr(expected)[0]);
  });

  test("should get correct customer location further from XML", () => {
    const expected = <Element[]>select(xpath.customer.location.further, dom);

    for (let i = 0; i < expected.length; i++) {
      expect(customer.location.further[0].content[i]._text).toBe(expected[i].textContent);
    }
  });

  /* TODO: setters */
});
