/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/GP_Temperature_v3.2.0_DCC.xml" }
 */

import { select, toTextArr, toTextContentArr } from "../../util";
import { ItemType, DCCDocument, IdentificationType } from "../../../src";

const base = "/dcc:digitalCalibrationCertificate/dcc:administrativeData/dcc:items";
const xpath = {
  items: {
    item: {
      name: {
        content: `${base}/dcc:item[1]/dcc:name/dcc:content`,
      },
      manufacturer: {
        name: {
          content: `${base}/dcc:item[1]/dcc:manufacturer/dcc:name/dcc:content`,
        },
      },
      model: `string(${base}/dcc:item[1]/dcc:model)`,
      identifications: {
        identification1: {
          issuer: `string(${base}/dcc:item[1]/dcc:identifications/dcc:identification[1]/dcc:issuer)`,
          value: `string(${base}/dcc:item[1]/dcc:identifications/dcc:identification[1]/dcc:value)`,
          name: {
            content: `${base}/dcc:item[1]/dcc:identifications/dcc:identification[1]/dcc:name/dcc:content`,
          },
        },
        identification2: {
          issuer: `string(${base}/dcc:item[1]/dcc:identifications/dcc:identification[2]/dcc:issuer)`,
          value: `string(${base}/dcc:item[1]/dcc:identifications/dcc:identification[2]/dcc:value)`,
          name: {
            content: `${base}/dcc:item[1]/dcc:identifications/dcc:identification[2]/dcc:name/dcc:content`,
          },
        },
        identification3: {
          issuer: `string(${base}/dcc:item[1]/dcc:identifications/dcc:identification[3]/dcc:issuer)`,
          value: `string(${base}/dcc:item[1]/dcc:identifications/dcc:identification[3]/dcc:value)`,
          name: {
            content: `${base}/dcc:item[1]/dcc:identifications/dcc:identification[3]/dcc:name/dcc:content`,
          },
        },
      },
      itemQuantities: {
        itemQuantity: {
          name: {
            content: `${base}/dcc:item[1]/dcc:itemQuantities/dcc:itemQuantity[1]/dcc:name/dcc:content`,
          },
          si_real: {
            si_value: `string(${base}/dcc:item[1]/dcc:itemQuantities/dcc:itemQuantity[1]/si:real/si:value)`,
            si_unit: `string(${base}/dcc:item[1]/dcc:itemQuantities/dcc:itemQuantity[1]/si:real/si:unit)`,
          },
        },
      },
      refType: `string(${base}/dcc:item[1]//@refType)`,
    },
  },
};

describe("GP_Temperature_v3.2.0_DCC: ItemType", () => {
  let dcc: DCCDocument, item: ItemType, identification1, identification2, identification3: IdentificationType, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    item = dcc.digitalCalibrationCertificate.administrativeData.items.item[0];
    identification1 = item.identifications.identification[0];
    identification2 = item.identifications.identification[1];
    identification3 = item.identifications.identification[2];
  });

  test("should get correct item name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.items.item.name.content, dom);
    expect(toTextArr(item.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct item manufacturer name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.items.item.manufacturer.name.content, dom);
    expect(toTextArr(item.manufacturer.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct item model from XML", () => {
    expect(item.model._text).toBe(select(xpath.items.item.model, dom));
  });

  test("should get correct identification 1 issuer from XML", () => {
    expect(identification1.issuer._text).toBe(select(xpath.items.item.identifications.identification1.issuer, dom));
  });

  test("should get correct identification 1 value from XML", () => {
    expect(identification1.value._text).toBe(select(xpath.items.item.identifications.identification1.value, dom));
  });

  test("should get correct identification 1 name content from XML", () => {
    const expected = <Element[]>select(xpath.items.item.identifications.identification1.name.content, dom);
    expect(toTextArr(identification1.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct identification 2 issuer from XML", () => {
    expect(identification2.issuer._text).toBe(select(xpath.items.item.identifications.identification2.issuer, dom));
  });

  test("should get correct identification 2 value from XML", () => {
    expect(identification2.value._text).toBe(select(xpath.items.item.identifications.identification2.value, dom));
  });

  test("should get correct identification 2 name content from XML", () => {
    const expected = <Element[]>select(xpath.items.item.identifications.identification2.name.content, dom);
    expect(toTextArr(identification2.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct identification 3 issuer from XML", () => {
    expect(identification3.issuer._text).toBe(select(xpath.items.item.identifications.identification3.issuer, dom));
  });

  test("should get correct identification 3 value from XML", () => {
    expect(identification3.value._text).toBe(select(xpath.items.item.identifications.identification3.value, dom));
  });

  test("should get correct identification 3 name content from XML", () => {
    const expected = <Element[]>select(xpath.items.item.identifications.identification3.name.content, dom);
    expect(toTextArr(identification3.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct item quantity name content from XML", () => {
    const expected = <Element[]>select(xpath.items.item.itemQuantities.itemQuantity.name.content, dom);
    expect(toTextArr(item.itemQuantities.itemQuantity[0].name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct item quantity real value from XML", () => {
    expect(item.itemQuantities.itemQuantity[0].real.value._text).toBe(select(xpath.items.item.itemQuantities.itemQuantity.si_real.si_value, dom));
  });

  test("should get correct item quantity real unit from XML", () => {
    expect(item.itemQuantities.itemQuantity[0].real.unit._text).toBe(select(xpath.items.item.itemQuantities.itemQuantity.si_real.si_unit, dom));
  });

  test("should get correct item refType from XML", () => {
    expect(item._attr.refType).toBe(select(xpath.items.item.refType, dom));
  });
  /* TODO: setters */
});
