/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/GP_Temperature_v3.2.0_DCC.xml" }
 */

import { select, toTextArr, toTextContentArr } from "../../util";
import { SoftwareListType, DCCDocument, SoftwareType } from "../../../src";

const base = "/dcc:digitalCalibrationCertificate/dcc:administrativeData/dcc:dccSoftware/dcc:software";
const xpath = {
  software: {
    name: {
      content: `${base}/dcc:name/dcc:content`,
    },
    release: `string(${base}/dcc:release)`,
    type: `string(${base}/dcc:type)`,
    description: {
      name: {
        content: `${base}/dcc:description/dcc:name/dcc:content`,
      },
      content: `${base}/dcc:description/dcc:content`,
    },
  },
};

describe("GP_Temperature_v3.2.0_DCC: DccSoftwareType", () => {
  let dcc: DCCDocument, dccSoftware: SoftwareListType, software: SoftwareType, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    dccSoftware = dcc.digitalCalibrationCertificate.administrativeData.dccSoftware;
    software = dccSoftware.software[0];
  });

  test("should get correct software name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.software.name.content, dom);
    expect(toTextArr(software.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct software release version of software from XML", () => {
    expect(software.release._text).toBe(select(xpath.software.release, dom));
  });

  test("should get correct software type of software from XML", () => {
    expect(software.type._text).toBe(select(xpath.software.type, dom));
  });

  test("should get correct description name content of software from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.software.description.name.content, dom);
    expect(toTextArr(software.description.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct description content of software from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.software.description.content, dom);
    expect(toTextArr(software.description.content)).toEqual(toTextContentArr(expected));
  });
});
