/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/GP_Temperature_v3.2.0_DCC.xml" }
 */

import { select, toTextArr, toTextContentArr } from "../../util";
import { DCCDocument, ResultType } from "../../../src";

const base = "/dcc:digitalCalibrationCertificate/dcc:measurementResults/dcc:measurementResult[1]/dcc:results";
const xpath = {
  measurementResults: {
    measurementResult: {
      results: {
        result: {
          name: {
            content: `${base}/dcc:result[1]/dcc:name/dcc:content`,
          },
          data: {
            list: {
              quantity1: {
                name: {
                  content: `${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[1]/dcc:name/dcc:content`,
                },
                si_hybrid: {
                  si_realListXMLList1: {
                    si_valueXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[1]/si:hybrid/si:realListXMLList[1]/si:valueXMLList)`,
                    si_unitXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[1]/si:hybrid/si:realListXMLList[1]/si:unitXMLList)`,
                  },
                  si_realListXMLList2: {
                    si_valueXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[1]/si:hybrid/si:realListXMLList[2]/si:valueXMLList)`,
                    si_unitXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[1]/si:hybrid/si:realListXMLList[2]/si:unitXMLList)`,
                  },
                },
                refType: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[1]//@refType)`,
              },
              quantity2: {
                name: {
                  content: `${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[2]/dcc:name/dcc:content`,
                },
                si_hybrid: {
                  si_realListXMLList1: {
                    si_valueXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[2]/si:hybrid/si:realListXMLList[1]/si:valueXMLList)`,
                    si_unitXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[2]/si:hybrid/si:realListXMLList[1]/si:unitXMLList)`,
                  },
                  si_realListXMLList2: {
                    si_valueXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[2]/si:hybrid/si:realListXMLList[2]/si:valueXMLList)`,
                    si_unitXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[2]/si:hybrid/si:realListXMLList[2]/si:unitXMLList)`,
                  },
                },
                refType: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[2]//@refType)`,
              },
              quantity3: {
                name: {
                  content: `${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/dcc:name/dcc:content`,
                },
                si_realListXMLList: {
                  si_valueXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/si:realListXMLList[1]/si:valueXMLList)`,
                  si_unitXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/si:realListXMLList[1]/si:unitXMLList)`,
                  si_expandedUncXMLList: {
                    si_uncertaintyXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/si:realListXMLList[1]/si:expandedUncXMLList/si:uncertaintyXMLList)`,
                    si_coverageFactorXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/si:realListXMLList[1]/si:expandedUncXMLList/si:coverageFactorXMLList)`,
                    si_coverageProbabilityXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/si:realListXMLList[1]/si:expandedUncXMLList/si:coverageProbabilityXMLList)`,
                    si_distributionXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/si:realListXMLList[1]/si:expandedUncXMLList/si:distributionXMLList)`,
                  },
                },
                measurementMetaData: {
                  metaData: {
                    declaration: {
                      name: {
                        content: `${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/dcc:measurementMetaData/dcc:metaData[1]/dcc:declaration/dcc:name/dcc:content`,
                      },
                    },
                    conformityXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/dcc:measurementMetaData/dcc:metaData/dcc:conformityXMLList)`,
                    data: {
                      quantity1: {
                        si_realListXMLList: {
                          si_valueXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/dcc:measurementMetaData/dcc:metaData/dcc:data/dcc:quantity[1]/si:realListXMLList/si:valueXMLList)`,
                          si_unitXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/dcc:measurementMetaData/dcc:metaData/dcc:data/dcc:quantity[1]/si:realListXMLList/si:unitXMLList)`,
                        },
                        refType: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/dcc:measurementMetaData/dcc:metaData/dcc:data/dcc:quantity[1]//@refType)`,
                      },
                      quantity2: {
                        si_realListXMLList: {
                          si_valueXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/dcc:measurementMetaData/dcc:metaData/dcc:data/dcc:quantity[2]/si:realListXMLList/si:valueXMLList)`,
                          si_unitXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/dcc:measurementMetaData/dcc:metaData/dcc:data/dcc:quantity[2]/si:realListXMLList/si:unitXMLList)`,
                        },
                        refType: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/dcc:measurementMetaData/dcc:metaData/dcc:data/dcc:quantity[2]//@refType)`,
                      },
                    },
                    refType: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/dcc:measurementMetaData/dcc:metaData//@refType)`,
                  },
                },
                refType: `string(${base}/dcc:result[1]/dcc:data/dcc:list/dcc:quantity[3]/@refType)`,
              },
              refType: `string(${base}/dcc:result[1]/dcc:data/dcc:list//@refType)`,
            },
            quantity1: {
              noQuantity: {
                name: {
                  content: `${base}/dcc:result[1]/dcc:data/dcc:quantity[1]/dcc:noQuantity/dcc:name/dcc:content`,
                },
                content: `${base}/dcc:result[1]/dcc:data/dcc:quantity[1]/dcc:noQuantity/dcc:content`,
                file: {
                  fileName: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[1]/dcc:noQuantity/dcc:file[1]/dcc:fileName)`,
                  mimeType: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[1]/dcc:noQuantity/dcc:file[1]/dcc:mimeType)`,
                  dataBase64: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[1]/dcc:noQuantity/dcc:file[1]/dcc:dataBase64)`,
                  refType: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[1]/dcc:noQuantity/dcc:file[1]//@refType)`,
                },
                formula: {
                  latex: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[1]/dcc:noQuantity/dcc:formula[1]/dcc:latex)`,
                },
              },
              refType: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[1]//@refType)`,
            },
            quantity2: {
              charsXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[2]/dcc:charsXMLList)`,
              refType: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[2]//@refType)`,
            },
            quantity3: {
              si_constant: {
                si_label: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[3]/si:constant/si:label)`,
                si_value: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[3]/si:constant/si:value)`,
                si_unit: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[3]/si:constant/si:unit)`,
                si_dateTime: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[3]/si:constant/si:dateTime)`,
              },
              refType: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[3]//@refType)`,
            },
            quantity4: {
              si_real: {
                si_label: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[4]/si:real/si:label)`,
                si_value: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[4]/si:real/si:value)`,
                si_unit: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[4]/si:real/si:unit)`,
                si_dateTime: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[4]/si:real/si:dateTime)`,
              },
              refType: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[4]//@refType)`,
            },
            quantity5: {
              si_realListXMLList: {
                si_labelXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[5]/si:realListXMLList/si:labelXMLList)`,
                si_valueXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[5]/si:realListXMLList/si:valueXMLList)`,
                si_unitXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[5]/si:realListXMLList/si:unitXMLList)`,
                si_dateTimeXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[5]/si:realListXMLList/si:dateTimeXMLList)`,
              },
              refType: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[5]//@refType)`,
            },
            quantity6: {
              si_hybrid: {
                si_constant1: {
                  si_label: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[6]/si:hybrid/si:constant[1]/si:label)`,
                  si_value: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[6]/si:hybrid/si:constant[1]/si:value)`,
                  si_unit: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[6]/si:hybrid/si:constant[1]/si:unit)`,
                  si_dateTime: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[6]/si:hybrid/si:constant[1]/si:dateTime)`,
                },
                si_constant2: {
                  si_label: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[6]/si:hybrid/si:constant[2]/si:label)`,
                  si_value: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[6]/si:hybrid/si:constant[2]/si:value)`,
                  si_unit: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[6]/si:hybrid/si:constant[2]/si:unit)`,
                  si_dateTime: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[6]/si:hybrid/si:constant[2]/si:dateTime)`,
                },
              },
              refType: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[6]//@refType)`,
            },
            quantity7: {
              si_hybrid: {
                si_real1: {
                  si_label: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[7]/si:hybrid/si:real[1]/si:label)`,
                  si_value: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[7]/si:hybrid/si:real[1]/si:value)`,
                  si_unit: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[7]/si:hybrid/si:real[1]/si:unit)`,
                  si_dateTime: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[7]/si:hybrid/si:real[1]/si:dateTime)`,
                },
                si_real2: {
                  si_label: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[7]/si:hybrid/si:real[2]/si:label)`,
                  si_value: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[7]/si:hybrid/si:real[2]/si:value)`,
                  si_unit: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[7]/si:hybrid/si:real[2]/si:unit)`,
                  si_dateTime: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[7]/si:hybrid/si:real[2]/si:dateTime)`,
                },
              },
              refType: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[7]//@refType)`,
            },
            quantity8: {
              si_hybrid: {
                si_realListXMLList1: {
                  si_labelXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[8]/si:hybrid/si:realListXMLList[1]/si:labelXMLList)`,
                  si_valueXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[8]/si:hybrid/si:realListXMLList[1]/si:valueXMLList)`,
                  si_unitXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[8]/si:hybrid/si:realListXMLList[1]/si:unitXMLList)`,
                  si_dateTimeXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[8]/si:hybrid/si:realListXMLList[1]/si:dateTimeXMLList)`,
                },
                si_realListXMLList2: {
                  si_labelXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[8]/si:hybrid/si:realListXMLList[2]/si:labelXMLList)`,
                  si_valueXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[8]/si:hybrid/si:realListXMLList[2]/si:valueXMLList)`,
                  si_unitXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[8]/si:hybrid/si:realListXMLList[2]/si:unitXMLList)`,
                  si_dateTimeXMLList: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[8]/si:hybrid/si:realListXMLList[2]/si:dateTimeXMLList)`,
                },
              },
              refType: `string(${base}/dcc:result[1]/dcc:data/dcc:quantity[8]//@refType)`,
            },
          },
          refType: `string(${base}/dcc:result[1]//@refType)`,
        },
      },
    },
  },
};

describe("GP_Temperature_v3.2.0_DCC: ResultType", () => {
  let dcc: DCCDocument, result: ResultType, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    result = dcc.digitalCalibrationCertificate.measurementResults.measurementResult[0].results.result[0];
  });

  test("should get correct result name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.results.result.name.content, dom);
    expect(toTextArr(result.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct result list quantity 1 name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.results.result.data.list.quantity1.name.content, dom);
    expect(toTextArr(result.data.list[0].quantity[0].name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct result list quantity 1 hybrid si:valueXMLList 1 from XML", () => {
    expect(result.data.list[0].quantity[0].hybrid.realListXMLList[0].valueXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity1.si_hybrid.si_realListXMLList1.si_valueXMLList, dom),
    );
  });

  test("should get correct result list quantity 1 hybrid si:unitXMLList 1 from XML", () => {
    expect(result.data.list[0].quantity[0].hybrid.realListXMLList[0].unitXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity1.si_hybrid.si_realListXMLList1.si_unitXMLList, dom),
    );
  });

  test("should get correct result list quantity 1 hybrid si:valueXMLList 2 from XML", () => {
    expect(result.data.list[0].quantity[0].hybrid.realListXMLList[1].valueXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity1.si_hybrid.si_realListXMLList2.si_valueXMLList, dom),
    );
  });

  test("should get correct result list quantity 1 hybrid si:unitXMLList 2: from XML", () => {
    expect(result.data.list[0].quantity[0].hybrid.realListXMLList[1].unitXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity1.si_hybrid.si_realListXMLList2.si_unitXMLList, dom),
    );
  });

  test("should get correct result list quantity 2 name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.results.result.data.list.quantity2.name.content, dom);
    expect(toTextArr(result.data.list[0].quantity[1].name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct result list quantity 2 hybrid si:valueXMLList 1 from XML", () => {
    expect(result.data.list[0].quantity[1].hybrid.realListXMLList[0].valueXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity2.si_hybrid.si_realListXMLList1.si_valueXMLList, dom),
    );
  });

  test("should get correct result list quantity 2 hybrid si:unitXMLList 1 from XML", () => {
    expect(result.data.list[0].quantity[1].hybrid.realListXMLList[0].unitXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity2.si_hybrid.si_realListXMLList1.si_unitXMLList, dom),
    );
  });

  test("should get correct result list quantity 2 hybrid si:valueXMLList 2 from XML", () => {
    expect(result.data.list[0].quantity[1].hybrid.realListXMLList[1].valueXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity2.si_hybrid.si_realListXMLList2.si_valueXMLList, dom),
    );
  });

  test("should get correct result list quantity 2 hybrid si:unitXMLList 2: from XML", () => {
    expect(result.data.list[0].quantity[1].hybrid.realListXMLList[1].unitXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity2.si_hybrid.si_realListXMLList2.si_unitXMLList, dom),
    );
  });

  test("should get correct result list quantity 3 name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.results.result.data.list.quantity3.name.content, dom);
    expect(toTextArr(result.data.list[0].quantity[2].name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct result list quantity 3 si:valueXMLList from XML", () => {
    expect(result.data.list[0].quantity[2].realListXMLList.valueXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity3.si_realListXMLList.si_valueXMLList, dom),
    );
  });

  test("should get correct result list quantity 3 si:unitXMLList from XML", () => {
    expect(result.data.list[0].quantity[2].realListXMLList.unitXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity3.si_realListXMLList.si_unitXMLList, dom),
    );
  });

  test("should get correct result list quantity 3 uncertainty list from XML", () => {
    expect(result.data.list[0].quantity[2].realListXMLList.expandedUncXMLList.uncertaintyXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity3.si_realListXMLList.si_expandedUncXMLList.si_uncertaintyXMLList, dom),
    );
  });

  test("should get correct result list quantity 3 uncertainty coverage factor list from XML", () => {
    expect(result.data.list[0].quantity[2].realListXMLList.expandedUncXMLList.coverageFactorXMLList._text).toBe(
      select(
        xpath.measurementResults.measurementResult.results.result.data.list.quantity3.si_realListXMLList.si_expandedUncXMLList.si_coverageFactorXMLList,
        dom,
      ),
    );
  });

  test("should get correct result list quantity 3 uncertainty coverage probability list from XML", () => {
    expect(result.data.list[0].quantity[2].realListXMLList.expandedUncXMLList.coverageProbabilityXMLList._text).toBe(
      select(
        xpath.measurementResults.measurementResult.results.result.data.list.quantity3.si_realListXMLList.si_expandedUncXMLList.si_coverageProbabilityXMLList,
        dom,
      ),
    );
  });

  test("should get correct result list quantity 3 uncertainty distribution list from XML", () => {
    expect(result.data.list[0].quantity[2].realListXMLList.expandedUncXMLList.distributionXMLList._text).toBe(
      select(
        xpath.measurementResults.measurementResult.results.result.data.list.quantity3.si_realListXMLList.si_expandedUncXMLList.si_distributionXMLList,
        dom,
      ),
    );
  });

  test("should get correct result list quantity 3 meta data declaration name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity3.measurementMetaData.metaData.declaration.name.content, dom)
    );
    expect(toTextArr(result.data.list[0].quantity[2].measurementMetaData.metaData[0].declaration.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct result list quantity 3 meta data conformityXMLList from XML", () => {
    expect(result.data.list[0].quantity[2].measurementMetaData.metaData[0].conformityXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity3.measurementMetaData.metaData.conformityXMLList, dom),
    );
  });

  test("should get correct result list quantity 3 meta data quantity 1 si:valueXMLList from XML", () => {
    expect(result.data.list[0].quantity[2].measurementMetaData.metaData[0].data.quantity[0].realListXMLList.valueXMLList._text).toBe(
      select(
        xpath.measurementResults.measurementResult.results.result.data.list.quantity3.measurementMetaData.metaData.data.quantity1.si_realListXMLList
          .si_valueXMLList,
        dom,
      ),
    );
  });

  test("should get correct result list quantity 3 meta data quantity 1 si:unitXMLList from XML", () => {
    expect(result.data.list[0].quantity[2].measurementMetaData.metaData[0].data.quantity[0].realListXMLList.unitXMLList._text).toBe(
      select(
        xpath.measurementResults.measurementResult.results.result.data.list.quantity3.measurementMetaData.metaData.data.quantity1.si_realListXMLList
          .si_unitXMLList,
        dom,
      ),
    );
  });

  test("should get correct result list quantity 3 meta data quantity 2 si:valueXMLList from XML", () => {
    expect(result.data.list[0].quantity[2].measurementMetaData.metaData[0].data.quantity[1].realListXMLList.valueXMLList._text).toBe(
      select(
        xpath.measurementResults.measurementResult.results.result.data.list.quantity3.measurementMetaData.metaData.data.quantity2.si_realListXMLList
          .si_valueXMLList,
        dom,
      ),
    );
  });

  test("should get correct result list quantity 3 meta data quantity 2 si:valueXMLList from XML", () => {
    expect(result.data.list[0].quantity[2].measurementMetaData.metaData[0].data.quantity[1].realListXMLList.valueXMLList._text).toBe(
      select(
        xpath.measurementResults.measurementResult.results.result.data.list.quantity3.measurementMetaData.metaData.data.quantity2.si_realListXMLList
          .si_valueXMLList,
        dom,
      ),
    );
  });

  test("should get correct result list quantity 3 meta data quantity 2 si:unitXMLList from XML", () => {
    expect(result.data.list[0].quantity[2].measurementMetaData.metaData[0].data.quantity[1].realListXMLList.unitXMLList._text).toBe(
      select(
        xpath.measurementResults.measurementResult.results.result.data.list.quantity3.measurementMetaData.metaData.data.quantity2.si_realListXMLList
          .si_unitXMLList,
        dom,
      ),
    );
  });

  test("should get correct result refType from XML", () => {
    expect(result._attr.refType).toBe(select(xpath.measurementResults.measurementResult.results.result.refType, dom));
  });

  test("should get correct result data list refType from XML", () => {
    expect(result.data.list[0]._attr.refType).toBe(select(xpath.measurementResults.measurementResult.results.result.data.list.refType, dom));
  });

  test("should get correct result list quantity 1 refType from XML", () => {
    expect(result.data.list[0].quantity[0]._attr.refType).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity1.refType, dom),
    );
  });

  test("should get correct result list quantity2 refType from XML", () => {
    expect(result.data.list[0].quantity[1]._attr.refType).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity2.refType, dom),
    );
  });

  test("should get correct result list quantity3 refType from XML", () => {
    expect(result.data.list[0].quantity[2]._attr.refType).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity3.refType, dom),
    );
  });

  test("should get correct result list quantity 3 meta data refType from XML", () => {
    expect(result.data.list[0].quantity[2].measurementMetaData.metaData[0]._attr.refType).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity3.measurementMetaData.metaData.refType, dom),
    );
  });

  test("should get correct result list quantity 2 refType from XML", () => {
    expect(result.data.list[0].quantity[1]._attr.refType).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity2.refType, dom),
    );
  });

  test("should get correct result list quantity 3 refType from XML", () => {
    expect(result.data.list[0].quantity[2]._attr.refType).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.list.quantity3.refType, dom),
    );
  });

  test("should get correct result no quantity name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.results.result.data.quantity1.noQuantity.name.content, dom);
    expect(toTextArr(result.data.quantity[0].noQuantity.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct result no quantity content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.results.result.data.quantity1.noQuantity.content, dom);
    expect(toTextArr(result.data.quantity[0].noQuantity.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct result no quantity file fileName from XML", () => {
    expect(result.data.quantity[0].noQuantity.file[0].fileName._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity1.noQuantity.file.fileName, dom),
    );
  });

  test("should get correct result no quantity file mimeType from XML", () => {
    expect(result.data.quantity[0].noQuantity.file[0].mimeType._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity1.noQuantity.file.mimeType, dom),
    );
  });

  test("should get correct result no quantity file dataBase64 from XML", () => {
    expect(result.data.quantity[0].noQuantity.file[0].dataBase64._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity1.noQuantity.file.dataBase64, dom),
    );
  });

  test("should get correct result no quantity file refType from XML", () => {
    expect(result.data.quantity[0].noQuantity.file[0]._attr.refType).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity1.noQuantity.file.refType, dom),
    );
  });

  test("should get correct result no quantity formula latex from XML", () => {
    expect(result.data.quantity[0].noQuantity.formula[0].latex._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity1.noQuantity.formula.latex, dom),
    );
  });

  test("should get correct result no quantity file refType from XML", () => {
    expect(result.data.quantity[0].noQuantity.file[0]._attr.refType).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity1.noQuantity.file.refType, dom),
    );
  });

  test("should get correct result charsXMLList value from XML", () => {
    expect(result.data.quantity[1].charsXMLList._text).toBe(select(xpath.measurementResults.measurementResult.results.result.data.quantity2.charsXMLList, dom));
  });

  test("should get correct result const label from XML", () => {
    expect(result.data.quantity[2].constant.label._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity3.si_constant.si_label, dom),
    );
  });

  test("should get correct result const value from XML", () => {
    expect(result.data.quantity[2].constant.value._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity3.si_constant.si_value, dom),
    );
  });

  test("should get correct result const unit from XML", () => {
    expect(result.data.quantity[2].constant.unit._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity3.si_constant.si_unit, dom),
    );
  });

  test("should get correct result const dateTime from XML", () => {
    expect(result.data.quantity[2].constant.dateTime._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity3.si_constant.si_dateTime, dom),
    );
  });

  test("should get correct result real label from XML", () => {
    expect(result.data.quantity[3].real.label._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity4.si_real.si_label, dom),
    );
  });

  test("should get correct result real value from XML", () => {
    expect(result.data.quantity[3].real.value._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity4.si_real.si_value, dom),
    );
  });

  test("should get correct result real unit from XML", () => {
    expect(result.data.quantity[3].real.unit._text).toBe(select(xpath.measurementResults.measurementResult.results.result.data.quantity4.si_real.si_unit, dom));
  });

  test("should get correct result real dateTime from XML", () => {
    expect(result.data.quantity[3].real.dateTime._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity4.si_real.si_dateTime, dom),
    );
  });

  test("should get correct result realListXMLList label list from XML", () => {
    expect(result.data.quantity[4].realListXMLList.labelXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity5.si_realListXMLList.si_labelXMLList, dom),
    );
  });

  test("should get correct result realListXMLList value list from XML", () => {
    expect(result.data.quantity[4].realListXMLList.valueXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity5.si_realListXMLList.si_valueXMLList, dom),
    );
  });

  test("should get correct result realListXMLList unit list from XML", () => {
    expect(result.data.quantity[4].realListXMLList.unitXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity5.si_realListXMLList.si_unitXMLList, dom),
    );
  });

  test("should get correct result realListXMLList dateTime list from XML", () => {
    expect(result.data.quantity[4].realListXMLList.dateTimeXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity5.si_realListXMLList.si_dateTimeXMLList, dom),
    );
  });

  test("should get correct result hybrid const 1 label from XML", () => {
    expect(result.data.quantity[5].hybrid.constant[0].label._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity6.si_hybrid.si_constant1.si_label, dom),
    );
  });

  test("should get correct result hybrid const 1 value from XML", () => {
    expect(result.data.quantity[5].hybrid.constant[0].value._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity6.si_hybrid.si_constant1.si_value, dom),
    );
  });

  test("should get correct result hybrid const 1 unit from XML", () => {
    expect(result.data.quantity[5].hybrid.constant[0].unit._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity6.si_hybrid.si_constant1.si_unit, dom),
    );
  });

  test("should get correct result hybrid const 1 dateTime from XML", () => {
    expect(result.data.quantity[5].hybrid.constant[0].dateTime._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity6.si_hybrid.si_constant1.si_dateTime, dom),
    );
  });

  test("should get correct result hybrid const 2 label from XML", () => {
    expect(result.data.quantity[5].hybrid.constant[1].label._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity6.si_hybrid.si_constant2.si_label, dom),
    );
  });

  test("should get correct result hybrid const 2 value from XML", () => {
    expect(result.data.quantity[5].hybrid.constant[1].value._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity6.si_hybrid.si_constant2.si_value, dom),
    );
  });

  test("should get correct result hybrid const 2 unit from XML", () => {
    expect(result.data.quantity[5].hybrid.constant[1].unit._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity6.si_hybrid.si_constant2.si_unit, dom),
    );
  });

  test("should get correct result hybrid const 2 dateTime from XML", () => {
    expect(result.data.quantity[5].hybrid.constant[1].dateTime._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity6.si_hybrid.si_constant2.si_dateTime, dom),
    );
  });

  test("should get correct result hybrid real 1 label from XML", () => {
    expect(result.data.quantity[6].hybrid.real[0].label._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity7.si_hybrid.si_real1.si_label, dom),
    );
  });

  test("should get correct result hybrid real 1 value from XML", () => {
    expect(result.data.quantity[6].hybrid.real[0].value._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity7.si_hybrid.si_real1.si_value, dom),
    );
  });

  test("should get correct result hybrid real 1 unit from XML", () => {
    expect(result.data.quantity[6].hybrid.real[0].unit._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity7.si_hybrid.si_real1.si_unit, dom),
    );
  });

  test("should get correct result hybrid real 1 dateTime from XML", () => {
    expect(result.data.quantity[6].hybrid.real[0].dateTime._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity7.si_hybrid.si_real1.si_dateTime, dom),
    );
  });

  test("should get correct result hybrid real 2 label from XML", () => {
    expect(result.data.quantity[6].hybrid.real[1].label._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity7.si_hybrid.si_real2.si_label, dom),
    );
  });

  test("should get correct result hybrid real 2 value from XML", () => {
    expect(result.data.quantity[6].hybrid.real[1].value._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity7.si_hybrid.si_real2.si_value, dom),
    );
  });

  test("should get correct result hybrid real 2 unit from XML", () => {
    expect(result.data.quantity[6].hybrid.real[1].unit._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity7.si_hybrid.si_real2.si_unit, dom),
    );
  });

  test("should get correct result hybrid real 2 dateTime from XML", () => {
    expect(result.data.quantity[6].hybrid.real[1].dateTime._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity7.si_hybrid.si_real2.si_dateTime, dom),
    );
  });

  test("should get correct result hybrid realListXMLList 1 label from XML", () => {
    expect(result.data.quantity[7].hybrid.realListXMLList[0].labelXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity8.si_hybrid.si_realListXMLList1.si_labelXMLList, dom),
    );
  });

  test("should get correct result hybrid realListXMLList 1 value from XML", () => {
    expect(result.data.quantity[7].hybrid.realListXMLList[0].valueXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity8.si_hybrid.si_realListXMLList1.si_valueXMLList, dom),
    );
  });

  test("should get correct result hybrid realListXMLList 1 unit from XML", () => {
    expect(result.data.quantity[7].hybrid.realListXMLList[0].unitXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity8.si_hybrid.si_realListXMLList1.si_unitXMLList, dom),
    );
  });

  test("should get correct result hybrid realListXMLList 1 dateTime from XML", () => {
    expect(result.data.quantity[7].hybrid.realListXMLList[0].dateTimeXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity8.si_hybrid.si_realListXMLList1.si_dateTimeXMLList, dom),
    );
  });

  test("should get correct result hybrid realListXMLList 2 label from XML", () => {
    expect(result.data.quantity[7].hybrid.realListXMLList[1].labelXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity8.si_hybrid.si_realListXMLList2.si_labelXMLList, dom),
    );
  });

  test("should get correct result hybrid realListXMLList 2 value from XML", () => {
    expect(result.data.quantity[7].hybrid.realListXMLList[1].valueXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity8.si_hybrid.si_realListXMLList2.si_valueXMLList, dom),
    );
  });

  test("should get correct result hybrid realListXMLList 2 unit from XML", () => {
    expect(result.data.quantity[7].hybrid.realListXMLList[1].unitXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity8.si_hybrid.si_realListXMLList2.si_unitXMLList, dom),
    );
  });

  test("should get correct result hybrid realListXMLList 2 dateTime from XML", () => {
    expect(result.data.quantity[7].hybrid.realListXMLList[1].dateTimeXMLList._text).toBe(
      select(xpath.measurementResults.measurementResult.results.result.data.quantity8.si_hybrid.si_realListXMLList2.si_dateTimeXMLList, dom),
    );
  });

  test("should get correct result no quantity refType from XML", () => {
    expect(result.data.quantity[0]._attr.refType).toBe(select(xpath.measurementResults.measurementResult.results.result.data.quantity1.refType, dom));
  });

  test("should get correct result charsXMLList refType from XML", () => {
    expect(result.data.quantity[1]._attr.refType).toBe(select(xpath.measurementResults.measurementResult.results.result.data.quantity2.refType, dom));
  });

  test("should get correct result const refType from XML", () => {
    expect(result.data.quantity[2]._attr.refType).toBe(select(xpath.measurementResults.measurementResult.results.result.data.quantity3.refType, dom));
  });

  test("should get correct result real refType from XML", () => {
    expect(result.data.quantity[3]._attr.refType).toBe(select(xpath.measurementResults.measurementResult.results.result.data.quantity4.refType, dom));
  });

  test("should get correct result realListXMLList refType from XML", () => {
    expect(result.data.quantity[4]._attr.refType).toBe(select(xpath.measurementResults.measurementResult.results.result.data.quantity5.refType, dom));
  });

  test("should get correct result hybrid const refType from XML", () => {
    expect(result.data.quantity[5]._attr.refType).toBe(select(xpath.measurementResults.measurementResult.results.result.data.quantity6.refType, dom));
  });

  test("should get correct result hybrid real refType from XML", () => {
    expect(result.data.quantity[6]._attr.refType).toBe(select(xpath.measurementResults.measurementResult.results.result.data.quantity7.refType, dom));
  });

  test("should get correct result hybrid realListXMLList refType from XML", () => {
    expect(result.data.quantity[7]._attr.refType).toBe(select(xpath.measurementResults.measurementResult.results.result.data.quantity8.refType, dom));
  });

  /* TODO: setters */
});
