/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/GP_Temperature_v3.2.1_DCC.xml" }
 */

import { select } from "../../util";
import { CoreDataType, DCCDocument } from "../../../src";

const base = "/dcc:digitalCalibrationCertificate/dcc:administrativeData/dcc:coreData/dcc:reportAmendedSubstituted";
const xpath = {
  reportAmendedSubstituted: {
    typeOfChange: `string(${base}/dcc:typeOfChange)`,
    replacedUniqueIdentifier: `string(${base}/dcc:replacedUniqueIdentifier)`,
    refType: `string(${base}//@refType)`,
    id: `string(${base}//@id)`,
  },
};

describe("GP_Temperature_v3.2.1_DCC: CoreDataType", () => {
  let dcc: DCCDocument, coreData: CoreDataType, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    coreData = dcc.digitalCalibrationCertificate.administrativeData.coreData;
  });

  test("should get correct reportAmendedSubstituted typeOfChange from XML", () => {
    expect(coreData.reportAmendedSubstituted.typeOfChange._text).toBe(select(xpath.reportAmendedSubstituted.typeOfChange, dom));
  });

  test("should get correct reportAmendedSubstituted replacedUniqueIdentifier from XML", () => {
    expect(coreData.reportAmendedSubstituted.replacedUniqueIdentifier._text).toBe(select(xpath.reportAmendedSubstituted.replacedUniqueIdentifier, dom));
  });

  test("should get correct reportAmendedSubstituted refType from XML", () => {
    expect(coreData.reportAmendedSubstituted._attr.refType).toBe(select(xpath.reportAmendedSubstituted.refType, dom));
  });

  test("should get correct reportAmendedSubstituted id from XML", () => {
    expect(coreData.reportAmendedSubstituted._attr.id).toBe(select(xpath.reportAmendedSubstituted.id, dom));
  });
});
