/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/example.xml" }
 */

import { select, toTextArr, toTextContentArr } from "../util";
import { DCCDocument, MeasurementResultType, UsedMethodListType, UsedMethodType } from "../../src";

const base = "/dcc:digitalCalibrationCertificate/dcc:measurementResults/dcc:measurementResult[1]";
const xpath = {
  measurementResults: {
    measurementResult: {
      usedMethods: {
        usedMethod1: {
          name: {
            content: `${base}/dcc:usedMethods/dcc:usedMethod[1]/dcc:name/dcc:content`,
          },
          description: {
            content: `${base}/dcc:usedMethods/dcc:usedMethod[1]/dcc:description/dcc:content`,
            contentDE: `${base}/dcc:usedMethods/dcc:usedMethod[1]/dcc:description/dcc:content[@lang='de']`,
            contentEN: `${base}/dcc:usedMethods/dcc:usedMethod[1]/dcc:description/dcc:content[@lang='en']`,
          },
          norm: `string(${base}/dcc:usedMethods/dcc:usedMethod[1]/dcc:norm[1])`,
          refType: `string(${base}/dcc:usedMethods/dcc:usedMethod[1]//@refType)`,
        },
        usedMethod2: {
          name: {
            content: `${base}/dcc:usedMethods/dcc:usedMethod[2]/dcc:name/dcc:content`,
          },
          norm: `string(${base}/dcc:usedMethods/dcc:usedMethod[2]/dcc:norm[1])`,
          refType: `string(${base}/dcc:usedMethods/dcc:usedMethod[2]//@refType)`,
        },
      },
    },
  },
};

describe("UsedMethodListType", () => {
  let dcc: DCCDocument, usedMethods: UsedMethodListType, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    usedMethods = dcc.digitalCalibrationCertificate.measurementResults.measurementResult[0].usedMethods;
  });

  test("should get correct used method 1 name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.usedMethods.usedMethod1.name.content, dom);
    expect(toTextArr(usedMethods.usedMethod[0].name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct used method 1 description content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.usedMethods.usedMethod1.description.content, dom);
    expect(toTextArr(usedMethods.usedMethod[0].description.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct used method 1 norm from XML", () => {
    expect(usedMethods.usedMethod[0].norm[0]._text).toBe(select(xpath.measurementResults.measurementResult.usedMethods.usedMethod1.norm, dom));
  });

  test("should get correct used method 1 refType from XML", () => {
    expect(usedMethods.usedMethod[0]._attr.refType).toBe(select(xpath.measurementResults.measurementResult.usedMethods.usedMethod1.refType, dom));
  });

  test("should get correct used method 2 name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.measurementResults.measurementResult.usedMethods.usedMethod2.name.content, dom);
    expect(toTextArr(usedMethods.usedMethod[1].name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct used method 2 norm from XML", () => {
    expect(usedMethods.usedMethod[1].norm[0]._text).toBe(select(xpath.measurementResults.measurementResult.usedMethods.usedMethod2.norm, dom));
  });

  test("should get correct used method 2 refType from XML", () => {
    expect(usedMethods.usedMethod[1]._attr.refType).toBe(select(xpath.measurementResults.measurementResult.usedMethods.usedMethod2.refType, dom));
  });

  /* TODO: setters */
});
