/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/Test_DCC_Minimal.xml" }
 */

import { select, toTextArr, toTextContentArr } from "../../util";
import { CalibrationLaboratoryType, DCCDocument } from "../../../src";

const base = "/dcc:digitalCalibrationCertificate/dcc:administrativeData/dcc:calibrationLaboratory/dcc:contact";
const xpath = {
  name: `string(${base}/dcc:name/dcc:content)`,
  location: {
    city: `${base}/dcc:location/dcc:city`,
  },
};

describe("Test_DCC_Minimal: CalibrationLaboratoryType", () => {
  let dcc: DCCDocument, calibrationLaboratory: CalibrationLaboratoryType, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    calibrationLaboratory = dcc.digitalCalibrationCertificate.administrativeData.calibrationLaboratory;
  });

  test("should get correct name from XML", () => {
    expect(calibrationLaboratory.contact.name.content[0]._text).toBe(select(xpath.name, dom));
  });

  test("should get correct city from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.location.city, dom);
    expect(toTextArr(calibrationLaboratory.contact.location.city)).toEqual(toTextContentArr(expected));
  });
});
