/**
 * @vitest-environment-options { "xmlPath": "./tests/resources/Test_DCC_Minimal.xml" }
 */

import { select, toTextArr, toTextContentArr } from "../../util";
import { ItemType, DCCDocument, IdentificationType } from "../../../src";

const base = "/dcc:digitalCalibrationCertificate/dcc:administrativeData/dcc:items";
const xpath = {
  items: {
    item: {
      name: {
        content: `${base}/dcc:item[1]/dcc:name/dcc:content`,
      },
      manufacturer: {
        name: {
          content: `${base}/dcc:item[1]/dcc:manufacturer/dcc:name/dcc:content`,
        },
      },
      identifications: {
        identification: {
          issuer: `string(${base}/dcc:item[1]/dcc:identifications/dcc:identification[1]/dcc:issuer)`,
          value: `string(${base}/dcc:item[1]/dcc:identifications/dcc:identification[1]/dcc:value)`,
          name: {
            content: `${base}/dcc:item[1]/dcc:identifications/dcc:identification[1]/dcc:name/dcc:content`,
          },
        },
      },
    },
  },
};

describe("Test_DCC_Minimal: ItemType", () => {
  let dcc: DCCDocument, item: ItemType, identification: IdentificationType, dom;

  beforeEach(() => {
    ({ dcc, dom } = recreateEnv());
    item = dcc.digitalCalibrationCertificate.administrativeData.items.item[0];
    identification = item.identifications.identification[0];
  });

  test("should get correct item name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.items.item.name.content, dom);
    expect(toTextArr(item.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct item manufacturer name content from XML", () => {
    // get expected list from example xml
    const expected = <Element[]>select(xpath.items.item.manufacturer.name.content, dom);
    expect(toTextArr(item.manufacturer.name.content)).toEqual(toTextContentArr(expected));
  });

  test("should get correct identification issuer from XML", () => {
    expect(identification.issuer._text).toBe(select(xpath.items.item.identifications.identification.issuer, dom));
  });

  test("should get correct identification value from XML", () => {
    expect(identification.value._text).toBe(select(xpath.items.item.identifications.identification.value, dom));
  });

  /* TODO: setters */
});
